..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

==================== ==================== ====================
AVL tree             height               postorder traversal
balance factor       inorder traversal    preorder traversal
binary heap          leaf node            priority queue
binary search tree   level                root 
binary tree          map                  rotation
BST property         min/max heap         sibling
child / children     node                 subtree
complete binary tree parent               successor 
edge                 parse tree           tree
heap order property  path                 tree traversal
==================== ==================== ====================

.. _tree_discuss:

